@@ -41,14 +41,14 @@ class StructuralAssessment(object):
         ID of the biomass reactions. If None, the method will try to find it
         automatically.
     atpm_id : str, optional
-        ID of the ATP maintenance reaction.   
+        ID of the ATP maintenance reaction.
     """
 
     def __init__(
         self,
         model: cobra.Model,
         biomass_id: Optional[str] = None,
-        atpm_id: str = 'ATPM'
+        atpm_id: str = "ATPM",
     ):
         # Enumerate all the internal cycles of the network and select the ones that must
         # be active in any non-zero solution.
@@ -59,7 +59,8 @@ class StructuralAssessment(object):
         self._forced_internal_cycles = []
         for cycle in forced_cycles.T:
             cycle_reaction_ids = [
-                model.reactions[i].id for i, v in enumerate(cycle) if v != 0]
+                model.reactions[i].id for i, v in enumerate(cycle) if v != 0
+            ]
             self._forced_internal_cycles.append(cycle_reaction_ids)
 
     @property
@@ -71,44 +72,46 @@ class StructuralAssessment(object):
         return self._forced_internal_cycles
 
     def summary(self):
-        """Print a summary of the structural assessment.
-        """
-        print('Strutural thermodynamic assessment summary:')
-        print('---------------------------------------------')
-        print('')
+        """Print a summary of the structural assessment."""
+        print("Strutural thermodynamic assessment summary:")
+        print("---------------------------------------------")
+        print("")
 
         pd_context = pd.option_context(
-            'display.max_rows', None,
-            'display.max_columns', None,
-            "display.precision", 3,
+            "display.max_rows",
+            None,
+            "display.max_columns",
+            None,
+            "display.precision",
+            3,
         )
 
         if len(self.forced_internal_cycles) > 0:
-            print('> The following internal cycles are thermodynamically '
-                  'unfeasible, but must be active in any non-zero flux '
-                  'solution, meaning that the model is thermodynamically '
-                  'inconsistent. For the cycles below, please:\n (1) Verify and '
-                  'correct the direction of the irreversible reactions.\n (2) '
-                  'Remove reactions in cycles that are connected to the rest '
-                  'of the network through a single reaction (e.g. A -> B, '
-                  'B -> A, where only A participates in other reactions).\n '
-                  'Alternatively, you can use the StructuralAssessment.'
-                  'autoresolve() function to automatically curate the model.')
+            print(
+                "> The following internal cycles are thermodynamically "
+                "unfeasible, but must be active in any non-zero flux "
+                "solution, meaning that the model is thermodynamically "
+                "inconsistent. For the cycles below, please:\n (1) Verify and "
+                "correct the direction of the irreversible reactions.\n (2) "
+                "Remove reactions in cycles that are connected to the rest "
+                "of the network through a single reaction (e.g. A -> B, "
+                "B -> A, where only A participates in other reactions).\n "
+                "Alternatively, you can use the StructuralAssessment."
+                "autoresolve() function to automatically curate the model."
+            )
             for i, cycle in enumerate(self.forced_internal_cycles):
                 print(f'{i}. {", ".join(cycle)}')
         else:
-            print(f'> No thermodynamic inconsistencies detected in the model.')
-        print('')
+            print(f"> No thermodynamic inconsistencies detected in the model.")
+        print("")
 
     def autoresolve(
-        self,
-        model: cobra.Model,
-        default_bound: float = default_flux_bound
+        self, model: cobra.Model, default_bound: float = default_flux_bound
     ):
         """Attempt to automatically resolve thermodynamic inconsistencies. This method
         removes all reactions involved in dead-end cycles (internal cycles that
         exchange flux with the rest of the network through a single metabolite) and
-        makes all the reactions in the remaining cycles reversible. While this method 
+        makes all the reactions in the remaining cycles reversible. While this method
         should always resolve all inconsistencies, it is still recommended to inspect
         the inconsistencies and the curated model manually to verify that the model
         behave as expected. The output of the curation can be seen by enabling logging
@@ -126,12 +129,16 @@ class StructuralAssessment(object):
         """
         for cycle in self.forced_internal_cycles:
             if self._is_semi_disconnected_cycle(model, cycle):
-                logger.info('Removing all reactions of the dead-end cycle:'
-                            f' {", ".join(cycle)}.')
+                logger.info(
+                    "Removing all reactions of the dead-end cycle:"
+                    f' {", ".join(cycle)}.'
+                )
                 model.remove_reactions(cycle, remove_orphans=True)
             else:
-                logger.info('Removing bounds for all reactions in the cycle: '
-                            f'{", ".join(cycle)}.')
+                logger.info(
+                    "Removing bounds for all reactions in the cycle: "
+                    f'{", ".join(cycle)}.'
+                )
                 for rxn_id in cycle:
                     try:
                         reaction = model.reactions.get_by_id(rxn_id)
@@ -140,12 +147,8 @@ class StructuralAssessment(object):
                     reaction.lower_bound = -default_bound
                     reaction.upper_bound = default_bound
 
-    def _is_semi_disconnected_cycle(
-        self,
-        model: cobra.Model,
-        cycle: np.array
-    ) -> bool:
-        """Check whether a cycle is dead-end, i.e. it exchanges flux with the 
+    def _is_semi_disconnected_cycle(self, model: cobra.Model, cycle: np.array) -> bool:
+        """Check whether a cycle is dead-end, i.e. it exchanges flux with the
         rest of the network through a single metabolite only.
         """
         with model as model:
@@ -182,12 +185,9 @@ class StructuralAssessment(object):
         return True
 
     def _get_forced_internal_cycles(
-        self,
-        model: cobra.Model,
-        cycles: np.array
+        self, model: cobra.Model, cycles: np.array
     ) -> np.array:
-        """Select our of a list of cycles the ones that are forced.
-        """
+        """Select our of a list of cycles the ones that are forced."""
         forced_cycle_idxs = []
         for e in range(cycles.shape[1]):
             if self._is_forced_cycle(model, cycles[:, e]):
@@ -200,8 +200,7 @@ class StructuralAssessment(object):
         model: cobra.Model,
         cycle: np.array,
     ) -> bool:
-        """Check if a cycle is forced (must be active in any non-zero flux solution).
-        """
+        """Check if a cycle is forced (must be active in any non-zero flux solution)."""
         min_flux = 1e-6
         rxn_idxs = np.where(cycle != 0)[0].tolist()
 
@@ -217,28 +216,26 @@ class StructuralAssessment(object):
 
                         # If the chosen directions are not within the flux bounds of the
                         # model we can skip the iteration.
-                        if (direction_i > 0 and rxn_i.upper_bound <= 0) or \
-                            (direction_i < 0 and rxn_i.lower_bound >= 0) or \
-                            (direction_j < 0 and rxn_j.upper_bound <= 0) or \
-                                (direction_j > 0 and rxn_j.lower_bound >= 0):
+                        if (
+                            (direction_i > 0 and rxn_i.upper_bound <= 0)
+                            or (direction_i < 0 and rxn_i.lower_bound >= 0)
+                            or (direction_j < 0 and rxn_j.upper_bound <= 0)
+                            or (direction_j > 0 and rxn_j.lower_bound >= 0)
+                        ):
                             continue
 
                         # Set the direction of the cycle for the first reaction.
                         if direction_i > 0:
-                            rxn_i.lower_bound = max(
-                                rxn_i.lower_bound, min_flux)
+                            rxn_i.lower_bound = max(rxn_i.lower_bound, min_flux)
                         else:
-                            rxn_i.upper_bound = min(
-                                rxn_i.upper_bound, -min_flux)
+                            rxn_i.upper_bound = min(rxn_i.upper_bound, -min_flux)
 
                         # Set the opposite direction (with respect to the direction in
                         # the EFM) for the second reaction.
                         if direction_j < 0:
-                            rxn_j.lower_bound = max(
-                                rxn_j.lower_bound, min_flux)
+                            rxn_j.lower_bound = max(rxn_j.lower_bound, min_flux)
                         else:
-                            rxn_j.upper_bound = min(
-                                rxn_j.upper_bound, -min_flux)
+                            rxn_j.upper_bound = min(rxn_j.upper_bound, -min_flux)
 
                         # Check whether the model is feasible. If yes, there are
                         # thermodynamically feasible solutions for the set of
@@ -280,10 +277,14 @@ class QuantitativeAssessment(object):
         self._theta_z = z_score_threshold
         self._theta_s = shadow_price_threshold
         self._max_ex_conc = max_extracellular_conc or Q(
-            default_max_non_intracellular_conc_mM, 'mM')
-        self._is_intracellular = pd.DataFrame([
-            m.compartment not in non_intracellular_compartment_ids for
-            m in pmo_problem.T.metabolites])
+            default_max_non_intracellular_conc_mM, "mM"
+        )
+        self._is_intracellular = pd.DataFrame(
+            [
+                m.compartment not in non_intracellular_compartment_ids
+                for m in pmo_problem.T.metabolites
+            ]
+        )
 
         # Restrict the PMO problem to the predicted directions. This way, the
         # problem is not an MILP anymore and solvers should be able to return
@@ -291,32 +292,39 @@ class QuantitativeAssessment(object):
         orthant_pmo = pmo_problem.rebuild_for_directions(pmo_problem.d.value)
         status = orthant_pmo.solve()
 
-        assert status == 'optimal' or status == 'optimal_inaccurate'
-        if status == 'optimal_inaccurate':
-            logger.warning(
-                'Inaccurate solution found when computing shadow prices.')
+        assert status == "optimal" or status == "optimal_inaccurate"
+        if status == "optimal_inaccurate":
+            logger.warning("Inaccurate solution found when computing shadow prices.")
 
         # Assemble metabolite and reaction data in two data frames.
-        self._metabolites_df = pd.DataFrame({
-            'id': pmo_problem.F.metabolite_ids,
-            'conc': np.exp(pmo_problem.log_c).ravel() * 1000 if
-            pmo_problem.log_c is not None else np.nan,
-            'z_log_c': self._make_z_scores(pmo_problem, 'log_c')
-        })
+        self._metabolites_df = pd.DataFrame(
+            {
+                "id": pmo_problem.F.metabolite_ids,
+                "conc": np.exp(pmo_problem.log_c).ravel() * 1000
+                if pmo_problem.log_c is not None
+                else np.nan,
+                "z_log_c": self._make_z_scores(pmo_problem, "log_c"),
+            }
+        )
 
-        self._reactions_df = pd.DataFrame({
-            'id': pmo_problem.T.reaction_ids,
-            'v': pmo_problem.v[pmo_problem._rxn_idxs_F_to_T].ravel(),
-            'drg0': pmo_problem.drg0.ravel() if
-            pmo_problem.drg0 is not None else np.nan,
-            'drg': pmo_problem.drg.ravel() if
-            pmo_problem.drg is not None else np.nan,
-            'z_drg': self._make_z_scores(pmo_problem, 'drg'),
-            'z_drg0': self._make_z_scores(pmo_problem, 'drg0'),
-            'sp_drg': np.maximum(
-                orthant_pmo.sign_constraints[0].dual_value,
-                orthant_pmo.sign_constraints[1].dual_value).ravel()
-        })
+        self._reactions_df = pd.DataFrame(
+            {
+                "id": pmo_problem.T.reaction_ids,
+                "v": pmo_problem.v[pmo_problem._rxn_idxs_F_to_T].ravel(),
+                "drg0": pmo_problem.drg0.ravel()
+                if pmo_problem.drg0 is not None
+                else np.nan,
+                "drg": pmo_problem.drg.ravel()
+                if pmo_problem.drg is not None
+                else np.nan,
+                "z_drg": self._make_z_scores(pmo_problem, "drg"),
+                "z_drg0": self._make_z_scores(pmo_problem, "drg0"),
+                "sp_drg": np.maximum(
+                    orthant_pmo.sign_constraints[0].dual_value,
+                    orthant_pmo.sign_constraints[1].dual_value,
+                ).ravel(),
+            }
+        )
 
     @property
     def metabolites_df(self) -> pd.DataFrame:
@@ -346,99 +354,120 @@ class QuantitativeAssessment(object):
         return self._max_ex_conc
 
     def summary(self):
-        """Print a summary of the quantitative assessment.
-        """
+        """Print a summary of the quantitative assessment."""
 
-        print('Quantitative thermodynamic assessment summary:')
-        print('------------------------------------------------')
-        print('conentrations: mM, free energies: kJ/mol')
-        print('')
+        print("Quantitative thermodynamic assessment summary:")
+        print("------------------------------------------------")
+        print("conentrations: mM, free energies: kJ/mol")
+        print("")
 
         pd_context = pd.option_context(
-            'display.max_rows', None,
-            'display.max_columns', None,
-            "display.precision", 3,
+            "display.max_rows",
+            None,
+            "display.max_columns",
+            None,
+            "display.precision",
+            3,
         )
 
         # Search for anomalies based on concentration z-scores.
         anomalies_m_z = self.metabolites_df[
-            self.metabolites_df['z_log_c'].abs() > self.theta_z]
+            self.metabolites_df["z_log_c"].abs() > self.theta_z
+        ]
         anomalies_m_z = anomalies_m_z.reindex(
-            anomalies_m_z['z_log_c'].abs().sort_values(ascending=False).index)
+            anomalies_m_z["z_log_c"].abs().sort_values(ascending=False).index
+        )
         if not anomalies_m_z.empty:
-            print(f'> The following metabolites have been flagged as '
-                  f'anomalies because their predicted concentration has an '
-                  f'absolute z-score greater than {self.theta_z}:')
+            print(
+                f"> The following metabolites have been flagged as "
+                f"anomalies because their predicted concentration has an "
+                f"absolute z-score greater than {self.theta_z}:"
+            )
             with pd_context:
                 print(anomalies_m_z)
         else:
-            print(f'> No anomaly found in concentration z-scores.')
-        print('')
+            print(f"> No anomaly found in concentration z-scores.")
+        print("")
 
         # Search for anomalies based on maximum concentration.
-        max_ex_concentration_mM = self.max_ex_concentration.m_as('mM')
+        max_ex_concentration_mM = self.max_ex_concentration.m_as("mM")
         anomalies_m_m = self.metabolites_df[
-            (self.metabolites_df['conc'] >= max_ex_concentration_mM) &
-            ~pd.DataFrame(self._is_intracellular)[0] &
-            (self.metabolites_df['z_log_c'].abs() > 0)]
+            (self.metabolites_df["conc"] >= max_ex_concentration_mM)
+            & ~pd.DataFrame(self._is_intracellular)[0]
+            & (self.metabolites_df["z_log_c"].abs() > 0)
+        ]
         anomalies_m_m = anomalies_m_m.reindex(
-            anomalies_m_m['conc'].abs().sort_values(ascending=False).index)
+            anomalies_m_m["conc"].abs().sort_values(ascending=False).index
+        )
         if not anomalies_m_m.empty:
-            print(f'> The following non-intracellular metabolites have been '
-                  f'flagged as anomalies because they have concentation '
-                  f'greater than {max_ex_concentration_mM} mM:')
+            print(
+                f"> The following non-intracellular metabolites have been "
+                f"flagged as anomalies because they have concentation "
+                f"greater than {max_ex_concentration_mM} mM:"
+            )
             with pd_context:
                 print(anomalies_m_m)
         else:
-            print(f'> No anomaly found in non-intracellular concentrations.')
-        print('')
+            print(f"> No anomaly found in non-intracellular concentrations.")
+        print("")
 
         # Search for anomalies based on reaction z-scores.
         anomalies_r_z = self.reactions_df[
-            (self.reactions_df['z_drg'].abs() > self.theta_z) |
-            (self.reactions_df['z_drg0'].abs() > self.theta_z)]
-        anomalies_r_z = anomalies_r_z.reindex(anomalies_r_z[['z_drg', 'z_drg0']]
-                                              .abs().max(axis=1).sort_values(ascending=False).index)
+            (self.reactions_df["z_drg"].abs() > self.theta_z)
+            | (self.reactions_df["z_drg0"].abs() > self.theta_z)
+        ]
+        anomalies_r_z = anomalies_r_z.reindex(
+            anomalies_r_z[["z_drg", "z_drg0"]]
+            .abs()
+            .max(axis=1)
+            .sort_values(ascending=False)
+            .index
+        )
         if not anomalies_r_z.empty:
-            print(f'> The following reactions have been flagged as anomalies '
-                  f'because their predicted free energy or standard free '
-                  f'energy has an absolute z-score greater than {self.theta_z}:')
+            print(
+                f"> The following reactions have been flagged as anomalies "
+                f"because their predicted free energy or standard free "
+                f"energy has an absolute z-score greater than {self.theta_z}:"
+            )
             with pd_context:
                 print(anomalies_r_z)
         else:
-            print(f'> No anomaly found in free energy z-scores.')
-        print('')
+            print(f"> No anomaly found in free energy z-scores.")
+        print("")
 
         # Search for anomalies based on reaction shadow prices.
-        anomalies_r_s = self.reactions_df[
-            (self.reactions_df['sp_drg'] > self.theta_s)]
+        anomalies_r_s = self.reactions_df[(self.reactions_df["sp_drg"] > self.theta_s)]
         anomalies_r_s = anomalies_r_s.reindex(
-            anomalies_r_s['sp_drg'].sort_values(ascending=False).index)
+            anomalies_r_s["sp_drg"].sort_values(ascending=False).index
+        )
         if not anomalies_r_s.empty:
-            print(f'> The following reactions are predicted to impose strong '
-                  f'thermodynamic constraints on the network because their '
-                  f'shadow price is greater than {self.theta_s}:')
+            print(
+                f"> The following reactions are predicted to impose strong "
+                f"thermodynamic constraints on the network because their "
+                f"shadow price is greater than {self.theta_s}:"
+            )
             with pd_context:
                 print(anomalies_r_s)
         else:
-            print(f'> No significant thermodynamic constraints found.')
-        print('')
+            print(f"> No significant thermodynamic constraints found.")
+        print("")
 
     def _make_z_scores(
-        self,
-        pmo_problem: PmoProblem,
-        variable: str
+        self, pmo_problem: PmoProblem, variable: str
     ) -> Union[np.array, float]:
-        """Construct the z-scores for a specific type of variables.
-        """
-        if variable == 'log_c':
-            transform = pmo_problem.B.to_log_conc_transform[0]
-        elif variable == 'drg':
-            transform = pmo_problem.B.to_drg_transform[0]
-        elif variable == 'drg0':
-            transform = pmo_problem.B.to_drg0_transform[0]
+        """Construct the z-scores for a specific type of variables."""
+        transform = None
+        if variable == "log_c":
+            if pmo_problem.B.to_log_conc_transform is not None:
+                transform = pmo_problem.B.to_log_conc_transform[0]
+        elif variable == "drg":
+            if pmo_problem.B.to_drg_transform is not None:
+                transform = pmo_problem.B.to_drg_transform[0]
+        elif variable == "drg0":
+            if pmo_problem.B.to_drg0_transform is not None:
+                transform = pmo_problem.B.to_drg0_transform[0]
         else:
-            raise ValueError(f'Unsuppoted variable {variable}')
+            raise ValueError(f"Unsuppoted variable {variable}")
 
         if transform is None:
             return np.nan
@@ -453,18 +482,18 @@ class QuantitativeAssessment(object):
 def prepare_for_pta(
     model: cobra.Model,
     biomass_id: Optional[str] = None,
-    atpm_id: str = 'ATPM',
+    atpm_id: str = "ATPM",
     default_bound: float = default_flux_bound,
     autoresolve_inconsistencies: bool = True,
     remove_blocked_reactions: bool = True,
-    tighten_bounds: bool = True
+    tighten_bounds: bool = True,
 ):
     """Attempt to automatically prepare a model for use in PTA.
 
     This method performs three actions:
 
     * Runs structural assessment on the model and attempts to autoresolve possible
-      inconsistencies. 
+      inconsistencies.
     * Removes all blocked reactions from the model.
     * Runs FVA to tighten the flux bounds of each reaction.
 
@@ -476,7 +505,7 @@ def prepare_for_pta(
         ID of the biomass reactions. If None, the method will try to find it
         automatically.
     atpm_id : str, optional
-        ID of the ATP maintenance reaction.   
+        ID of the ATP maintenance reaction.
     default_bound : float, optional
         Default bound to use for unconstrained reactions.
     autoresolve_inconsistencies : bool, optional
@@ -484,7 +513,7 @@ def prepare_for_pta(
         false otherwise. By default True.
     remove_blocked_reactions : bool, optional
         True if the method should remove blocked reactions, false otherwise. By default
-        True. 
+        True.
     tighten_bounds : bool, optional
         True if the method should restrict the flux bounds with FVA, false otherwise. By
         default True.
@@ -497,10 +526,7 @@ def prepare_for_pta(
     # Remove blocked reactions to make sure that all reactions can have a
     # well-defined direction.
     if remove_blocked_reactions:
-        model.remove_reactions(
-            find_blocked_reactions(model),
-            remove_orphans=True
-        )
+        model.remove_reactions(find_blocked_reactions(model), remove_orphans=True)
 
     # Restrict reaction bounds using FVA.
     if tighten_bounds:
